==> smb4k_0.4.1a.orig.tar.gz: smb4k-0.4.1a/smb4k/widgets/smb4kshareoptions.h <==
/***************************************************************************
    smb4kshareoptions  -  description
                             -------------------
    begin                : Sa Nov 15 2003
    copyright            : (C) 2003 by Alexander Reinholdt
    email                : dustpuppy@mail.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SMB4KSHAREOPTIONS_H
#define SMB4KSHAREOPTIONS_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

// Qt includes
#include <qwidget.h>
#include <qcheckbox.h>

// KDE includes
#include <kurlrequester.h>

class Smb4KShareOptions : public QWidget
{
  friend class Smb4KOptionsDlg;
  
  Q_OBJECT
  public:
    /** The constructor. */
    Smb4KShareOptions( QWidget *parent = 0, const char *name = 0 );
    /** The destructor. */
    ~Smb4KShareOptions();

  private:
    KURLRequester *m_defaultPath;
    QCheckBox *m_cleanUp;
    QCheckBox *m_lowercase;
    QCheckBox *m_unmountAll;
    QCheckBox *m_mountRecent;
    QCheckBox *m_unmountDead;
    QCheckBox *m_useSuper;
    QCheckBox *m_allowUnmountForeign;
    KPushButton *m_removeSUEntries;

  protected slots:
    void slotRemoveClicked();
};
#endif

==> smb4k_0.5.2.orig.tar.gz: smb4k-0.5.2/smb4k/widgets/smb4kshareoptions.h <==
/***************************************************************************
    smb4kshareoptions  -  description
                             -------------------
    begin                : Sa Nov 15 2003
    copyright            : (C) 2003 by Alexander Reinholdt
    email                : dustpuppy@mail.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SMB4KSHAREOPTIONS_H
#define SMB4KSHAREOPTIONS_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

// Qt includes
#include <qwidget.h>
#include <qcheckbox.h>
#include <qradiobutton.h>

// KDE includes
#include <kurlrequester.h>

class Smb4KShareOptions : public QWidget
{
  friend class Smb4KOptionsDlg;
  
  Q_OBJECT
  public:
    /** 
     * The constructor. 
     */
    Smb4KShareOptions( QWidget *parent = 0, const char *name = 0 );
    /** 
     * The destructor. 
     */
    ~Smb4KShareOptions();

  private:
    KURLRequester *m_defaultPath;
    QCheckBox *m_lowercase;
    QCheckBox *m_unmountAll;
    QCheckBox *m_mountRecent;
    QCheckBox *m_allowUnmountForeign;
    KPushButton *m_removeSUEntries;
};
#endif
